==> nextcloud-16.0.5.tgz: nextcloud/apps/accessibility/l10n/fi.js <==
OC.L10N.register(
    "accessibility",
    {
    "Dark theme" : "Tumma teema",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness. It is still under development, so please report any issues you may find." : "Tumma teema helpottaa silmien rasitusta vähentämällä kokonaiskirkkautta. Teemaa kehitetään edelleen, joten ilmoitathan mahdollisesti kohtaamasi ongelmat.",
    "Dyslexia font" : "Lukihäiriökirjasin",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic on ilmainen kirjasin, joka on suunniteltu lieventämään lukihäiriön aiheuttamia lukuvirheitä.",
    "Accessibility" : "Saavutettavuus",
    "Accessibility options for nextcloud" : "Saavutettavuusvaihtoehdot Nextcloudille",
    "Provides multiple accessibilities options to ease your use of Nextcloud" : "Tarjoaa monia saavutettavuusvaihtoehtoja helpottamaan Nexcloudin käyttöä.",
    "Web Content Accessibility Guidelines" : "Verkkosisällön saavutettavuusohjeet",
    "our issue tracker" : "virheidenseurantajärjestelmämme",
    "our design team" : "suunnitteluryhmämme",
    "Enable" : "Ota käyttöön",
    "High contrast theme" : "Suuren kontrastin teema",
    "A high contrast theme to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Suuren kontrastin teema helpottaa navigointiasi. Visuaalinen laatu on heikompi, mutta selkeys paranee.",
    "Dark theme (beta)" : "Tumma teema (beta)",
    "Themes" : "Teemat",
    "Fonts" : "Fontit",
    "enabled" : "käytössä"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-18.0.3.tgz: nextcloud/apps/accessibility/l10n/fi.js <==
OC.L10N.register(
    "accessibility",
    {
    "Dark theme" : "Tumma teema",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness. It is still under development, so please report any issues you may find." : "Tumma teema helpottaa silmien rasitusta vähentämällä kokonaiskirkkautta. Teemaa kehitetään edelleen, joten ilmoitathan mahdollisesti kohtaamasi ongelmat.",
    "High contrast mode" : "Suuren kontrastin tila",
    "Dyslexia font" : "Lukihäiriökirjasin",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic on ilmainen kirjasin, joka on suunniteltu lieventämään lukihäiriön aiheuttamia lukuvirheitä.",
    "Accessibility" : "Saavutettavuus",
    "Accessibility options for nextcloud" : "Saavutettavuusvaihtoehdot Nextcloudille",
    "Provides multiple accessibilities options to ease your use of Nextcloud" : "Tarjoaa monia saavutettavuusvaihtoehtoja helpottamaan Nexcloudin käyttöä.",
    "High contrast theme" : "Suuren kontrastin teema",
    "A high contrast theme to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Suuren kontrastin teema helpottaa navigointiasi. Visuaalinen laatu on heikompi, mutta selkeys paranee.",
    "Dark theme (beta)" : "Tumma teema (beta)",
    "Web Content Accessibility Guidelines" : "Verkkosisällön saavutettavuusohjeet",
    "our issue tracker" : "virheidenseurantajärjestelmämme",
    "our design team" : "suunnitteluryhmämme",
    "Enable" : "Ota käyttöön"
},
"nplurals=2; plural=(n != 1);");
